#!/bin/bash

if [ -f '/usr/sbin/wildix_shell_tools' ]; then
	. /usr/sbin/wildix_shell_tools
else
	logger -t "${0}" "ERROR: can't include wildix_shell_tools"
	exit 1
fi

CORES="$1" ; RAM="$2" ; AMAZON="$3" ; DOCKER="$4"

if [ -z $CORES ] || [ -z $RAM ] || [ -z $AMAZON ] || [ -z $DOCKER ]; then
	log "ERROR: zero values (exit)" "${0##*/}"
	exit 0
fi


## clean up old stuff
LIST_OF_DELETE="
/etc/tmpfiles.d/wms-cache-shm.conf
/etc/tmpfiles.d/wms-cache-ssd.conf
/etc/tmpfiles.d/wms-mem-shm.conf
/etc/tmpfiles.d/wms-mem-ssd.conf
"

for file in $LIST_OF_DELETE; do
	[ -f "$file" ] && rm -f $file
done

## settings for wms-cache
WMS_CACHE_SHM="## wms cache dir in memory /tmp/wms_cache
d /rw/var/cache/wms 0777 wms wms -
L+ /tmp/wms_cache - - - - /rw/var/cache/wms"

WMS_CACHE_SSD="## wms cache dir on ssd /tmp/wms_cache
D /var/cache/wms 0755 wms wms -
L+ /tmp/wms_cache - - - - /var/cache/wms"

## settings for optimizing memory usage
WMS_MEM_SHM="## memory for WMS4
R /var/cache/wms_session
R /var/cache/wms_calls
d /rw/tmp/session/lighty 0777 root root - -"

WMS_MEM_SSD="## memory for WMS4
## callweaver
D /var/cache/wms_calls 0755 wms wms -
L+ /tmp/calls - - - - /var/cache/wms_calls
## php
D /var/cache/wms_session 0755 wms wms -
L+ /tmp/session/lighty - - - - /var/cache/wms_session"

## get md5 for config files
WMS_CACHE_MD5="$(md5sum /etc/tmpfiles.d/wms-cache.conf 2>/dev/null | awk '{print $1}')"
WMS_MEM_MD5="$(md5sum /etc/tmpfiles.d/wms-mem.conf 2>/dev/null | awk '{print $1}')"


## set chache for wms
if [ "$RAM" -le "1900" ]; then
	if [ "$WMS_CACHE_MD5" != "$(md5sum <<< "$WMS_CACHE_SSD" | awk '{print $1}')" ]; then
		log "Set wms-cache on disk." "${0##*/}"
		echo "$WMS_CACHE_SSD" > /etc/tmpfiles.d/wms-cache.conf
	fi
else
	if [ "$WMS_CACHE_MD5" != "$(md5sum <<< "$WMS_CACHE_SHM" | awk '{print $1}')" ]; then
		log "Set wms-cache in memory." "${0##*/}"
		echo "$WMS_CACHE_SHM" > /etc/tmpfiles.d/wms-cache.conf
	fi
fi

## optimization for pbx with low memory
if [ "$RAM" -le "500" ]; then
	if [ "$WMS_MEM_MD5" != "$(md5sum <<< "$WMS_MEM_SSD" | awk '{print $1}')" ]; then
		log "Optimization memory: profile small." "${0##*/}"
		echo "$WMS_MEM_SSD" > /etc/tmpfiles.d/wms-mem.conf

		## fix for switching profiles
		rm -rf /tmp/calls
		rm -rf /tmp/session/lighty
	fi
else
	if [ "$WMS_MEM_MD5" != "$(md5sum <<< "$WMS_MEM_SHM" | awk '{print $1}')" ]; then
		log "Optimization memory: profile middle or high." "${0##*/}"
		echo "$WMS_MEM_SHM" > /etc/tmpfiles.d/wms-mem.conf

		## fix for switching profiles
		rm -rf /tmp/calls
		rm -rf /tmp/session/lighty
	fi
fi

## re-generate checking previous kernel after reboot
[ -f "/etc/kernel/postinst.d/apt-auto-removal" ] && /bin/bash /etc/kernel/postinst.d/apt-auto-removal || true

## init config by tmpfilesd system
[ -f "/etc/tmpfiles.d/wms-cache.conf" ] && /bin/systemd-tmpfiles --create --remove /etc/tmpfiles.d/wms-cache.conf || true
[ -f "/etc/tmpfiles.d/wms-mem.conf" ] && /bin/systemd-tmpfiles --create --remove /etc/tmpfiles.d/wms-mem.conf || true
