#!/bin/bash

if [ -f '/usr/sbin/wildix_shell_tools' ]; then
  . /usr/sbin/wildix_shell_tools
else
  logger -t "${0}" "ERROR: can't include wildix_shell_tools"
  exit 1
fi

CORES="$1" ; RAM="$2" ; AMAZON="$3" ; DOCKER="$4"

if [ -z $CORES ] || [ -z $RAM ] || [ -z $AMAZON ] || [ -z $DOCKER ]; then
  log "ERROR: zero values (exit)" "${0##*/}"
  exit 0
fi

__ENABLE_SWAP(){
## $1 - SWAP-file name
## $2 - RAM size with a letter for fallocate -l and ls -lh commands

## swap file creation with $1 RAM
if [[ "`ls -lh $1 2> /dev/null | awk '{print $5}'`" != "$2" ]]; then
  __DISABLE_SWAP /root/swapfile
  log "Creating swap-file with $2 RAM." "${0##*/}"
  fallocate -l $2 $1
  chmod 0600 $1
  mkswap $1
fi

## swap unit file for automatic activation
if [ ! -s "/etc/systemd/system/root-swapfile.swap" ]; then
  cat << END > /etc/systemd/system/root-swapfile.swap
[Unit]
Description=Swap for nano instances

[Swap]
What=$1

[Install]
WantedBy=multi-user.target
END
fi

## enabling root-swapfile service if it's disabled
[[ "$(systemctl is-enabled root-swapfile.swap)" != "enabled" ]] && systemctl enable --now /etc/systemd/system/root-swapfile.swap

}

__DISABLE_SWAP(){
## $1 - SWAP-file name

  if [ -f $1 ]; then
    log "Cleaning up swap-file" "${0##*/}"
    systemctl stop root-swapfile.swap
    systemctl disable root-swapfile.swap
    rm -f $1
  fi

}

## for cloud instances
if [ "$AMAZON" = "1" ]; then

  if [ "$RAM" -le "500" ]; then
    ## set buffer pools to minimal possible value
    buffer_size=8M
    max_con=15
      __ENABLE_SWAP /root/swapfile 512M
    elif [ "$RAM" -le "1000" ]; then
      buffer_size=32M
      max_con=15
      if [[ `df / | awk 'FNR == 2 {print $4}'` -lt 1572864 ]]; then
          logger -s "$DATE_NOW Can't create 1G swap file, free disk space is less than 1.5G"
      else
          __ENABLE_SWAP /root/swapfile 1.0G
      fi
  elif [ "$RAM" -le "2000" ]; then
    buffer_size=256M
    max_con=50
    __DISABLE_SWAP /root/swapfile
  elif [ "$RAM" -le "4000" ]; then
    buffer_size=256M
    max_con=100
    __DISABLE_SWAP /root/swapfile
  else
    buffer_size=512M
    max_con=200
    __DISABLE_SWAP /root/swapfile
  fi

  ## alter mysql buffers
  if [ -d "/etc/mysql/mariadb.conf.d" ]; then
    cat << END > /etc/mysql/mariadb.conf.d/50-override.cnf
[mysqld]
innodb_buffer_pool_size = ${buffer_size}
max_connections = ${max_con}
innodb_flush_method = O_DIRECT
wait_timeout = 300
interactive_timeout = 300
END
  fi

  ## disable remote support monit rule
  [ -f '/etc/monit/openvpn.conf' ] && sed -i '/^#/!s/\(.*\)/#\1/g' /etc/monit/openvpn.conf

  ## disable remote support for all aws cloud !
  if [ "$(awk -F '=' '{print $2}' /rw2/etc/pbx/remote_support.config)" == "1" ]; then
    log "Disable remote support for aws cloud." "${0##*/}"
    echo "autostart=0" > /rw2/etc/pbx/remote_support.config
    systemctl stop openvpn@wildixclient.service
    systemctl disable openvpn@wildixclient.service
    systemctl disable openvpn
  fi

  ## disable snmp for all aws clouds
  if [ "$(systemctl is-enabled snmpd)" == "enabled" ]; then
    log "Disable snmpd for aws cloud." "${0##*/}"
    systemctl stop snmpd || true
    systemctl disable snmpd
  fi

  ## disable smartd for all aws clouds
  if [ "$(systemctl is-enabled smartd)" == "enabled" ]; then
    log "Disable smartd for aws cloud." "${0##*/}"
    systemctl stop smartd || true
    systemctl disable smartd
  fi

  ## changing directory for mysql tmp dir
  MYSQL_CFG='/etc/mysql/mariadb.conf.d/50-server.cnf'
  MYSQL_TMP_DIR='/var/log/mysql'

  if [ -s "$MYSQL_CFG" ] && [ "$(awk '/^tmpdir.*=/{print $3}' $MYSQL_CFG)" != "$MYSQL_TMP_DIR" ]; then
    sed -i -e "/^tmpdir.*=/ s/=.*/= $(sed 's/\//\\\//g' <<< $MYSQL_TMP_DIR)/" $MYSQL_CFG
  fi

fi
